@@ -5,7 +5,7 @@ use base 'Class::Data::Inheritable';
 use File::MMagic;
 use File::Slurp;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 __PACKAGE__->mk_classdata('mmagic');
 __PACKAGE__->mmagic( File::MMagic->new );
@@ -18,8 +18,12 @@ Catalyst::Plugin::Static - Serve static files with Catalyst
 
     use Catalyst 'Static';
 
+    # let File::MMagic determine the content type
     $c->serve_static;
 
+    # or specify explicitly if you know better
+    $c->serve_static('text/css');
+
 =head1 DESCRIPTION
 
 Serve static files from config->{root}.
@@ -35,7 +39,7 @@ sub serve_static {
     my $path = $c->config->{root} . '/' . $c->req->path;
     if ( -f $path ) {
         my $content = read_file($path);
-        my $type    = __PACKAGE__->mmagic->checktype_contents($content);
+        my $type = shift || __PACKAGE__->mmagic->checktype_contents($content);
         $c->res->headers->content_type($type);
         $c->res->output($content);
         $c->log->debug(qq/Serving file "$path" as "$type"/) if $c->debug;
@@ -52,6 +56,10 @@ L<Catalyst>.
 
 Sebastian Riedel, C<sri@cpan.org>
 
+=head1 THANK YOU
+
+Torsten Seemann and all the others who've helped.
+
 =head1 COPYRIGHT
 
 This program is free software, you can redistribute it and/or modify it under
